"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const index_1 = require("../index");
class Client {
    /**
     * @param {ClientCookieManager} cookieManager - The cookie manager to use.
     * @param {Object} options - The options to use.
     */
    constructor(cookieManager, options) {
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "cookieManager", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.cookieManager = cookieManager;
        this.options = options;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getAbyssBattle(uid, previous) {
        const cookie = this.cookieManager.get();
        const ltoken = cookie.ltoken;
        const ltuid = cookie.ltuid;
        const { language } = this.options;
        const res = new index_1.SpiralAbyss().get(language, `ltoken=${ltoken}; ltuid=${ltuid};`, uid, previous);
        return res;
    }
    /**
     * @param {string} uid - HoYolab uid.
     */
    async getGameRecordCard(uid) {
        const cookie = this.cookieManager.get();
        const ltoken = cookie.ltoken;
        const ltuid = cookie.ltuid;
        const { language } = this.options;
        const res = new index_1.GameRecordCard().get(language, `ltoken=${ltoken}; ltuid=${ltuid};`, uid);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getGenshinUser(uid) {
        const cookie = this.cookieManager.get();
        const ltoken = cookie.ltoken;
        const ltuid = cookie.ltuid;
        const { language } = this.options;
        const res = new index_1.GenshinUser().get(language, `ltoken=${ltoken}; ltuid=${ltuid};`, uid);
        return res;
    }
    /**
     * @param {string} uid - Genshin Impact game uid.
     */
    async getRealTimeNotes(uid) {
        const cookie = this.cookieManager.get();
        const ltoken = cookie.ltoken;
        const ltuid = cookie.ltuid;
        const { language } = this.options;
        const res = new index_1.RealTimeNotes().get(language, `ltoken=${ltoken}; ltuid=${ltuid};`, uid);
        return res;
    }
}
exports.Client = Client;
//# sourceMappingURL=client.js.map